@@ -7,13 +7,13 @@ import { config, locationService } from '@grafana/runtime';
 import {
   NewSceneObjectAddedEvent,
   PanelBuilders,
+  SceneComponentProps,
   SceneDataTransformer,
   SceneObjectBase,
   SceneObjectRef,
   SceneObjectState,
   SceneObjectStateChangedEvent,
   SceneQueryRunner,
-  sceneGraph,
   sceneUtils,
   VizPanel,
 } from '@grafana/scenes';
@@ -21,8 +21,6 @@ import { Panel } from '@grafana/schema';
 import { OptionFilter } from 'app/features/dashboard/components/PanelEditor/OptionsPaneOptions';
 import { getLastUsedDatasourceFromStorage } from 'app/features/dashboard/utils/dashboard';
 import { saveLibPanel } from 'app/features/library-panels/state/api';
-import { getAllSuggestions } from 'app/features/panel/suggestions/getAllSuggestions';
-import { hasData } from 'app/features/panel/suggestions/utils';
 
 import { DashboardEditActionEvent } from '../edit-pane/shared';
 import { DashboardSceneChangeTracker } from '../saving/DashboardSceneChangeTracker';
@@ -40,6 +38,8 @@ import {
 
 import { DataProviderSharer } from './PanelDataPane/DataProviderSharer';
 import { PanelDataPane } from './PanelDataPane/PanelDataPane';
+import { PanelDataPaneNext } from './PanelEditNext/PanelDataPaneNext';
+import { PanelEditorRendererNext } from './PanelEditNext/PanelEditorRendererNext';
 import { PanelEditorRenderer } from './PanelEditorRenderer';
 import { PanelOptionsPane } from './PanelOptionsPane';
 
@@ -47,21 +47,27 @@ export interface PanelEditorState extends SceneObjectState {
   isNewPanel: boolean;
   isDirty?: boolean;
   optionsPane?: PanelOptionsPane;
-  dataPane?: PanelDataPane;
+  dataPane?: PanelDataPane | PanelDataPaneNext;
   panelRef: SceneObjectRef<VizPanel>;
   showLibraryPanelSaveModal?: boolean;
   showLibraryPanelUnlinkModal?: boolean;
-  editPreview?: VizPanel;
   tableView?: VizPanel;
   pluginLoadErrror?: string;
   /**
    * Waiting for library panel or panel plugin to load
    */
   isInitializing?: boolean;
+  /**
+   * Enable the v2 query editor experience
+   */
+  useQueryExperienceNext?: boolean;
 }
 
 export class PanelEditor extends SceneObjectBase<PanelEditorState> {
-  static Component = PanelEditorRenderer;
+  static Component = ({ model }: SceneComponentProps<PanelEditor>) => {
+    const { useQueryExperienceNext } = model.useState();
+    return useQueryExperienceNext ? <PanelEditorRendererNext model={model} /> : <PanelEditorRenderer model={model} />;
+  };
 
   private _layoutItemState?: SceneObjectState;
   private _layoutItem: DashboardLayoutItem;
@@ -91,12 +97,9 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
     // Need to clear selection here since selection is activated when panel edit mode is entered through the panel actions menu. This causes sidebar panel editor to be open when exiting panel edit mode
     dashboard.state.editPane.clearSelection();
 
-    if (panel.state.pluginId === UNCONFIGURED_PANEL_PLUGIN_ID) {
-      if (config.featureToggles.newVizSuggestions) {
-        this._autoSelectVisualization(panel);
-      } else {
-        panel.changePluginType('timeseries');
-      }
+    // this will be deleted when suggestions is fully rolled out.
+    if (panel.state.pluginId === UNCONFIGURED_PANEL_PLUGIN_ID && !config.featureToggles.newVizSuggestions) {
+      panel.changePluginType('timeseries');
     }
 
     this._subs.add(
@@ -119,28 +122,6 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
     };
   }
 
-  private async _autoSelectVisualization(panel: VizPanel) {
-    const dataObject = sceneGraph.getData(panel);
-
-    this._subs.add(
-      dataObject.subscribeToState(async () => {
-        const { data } = dataObject.state;
-        if (hasData(data) && panel.state.pluginId === UNCONFIGURED_PANEL_PLUGIN_ID) {
-          const { suggestions } = await getAllSuggestions(data);
-
-          if (suggestions.length > 0) {
-            const defaultFirstSuggestion = suggestions[0];
-            await panel.changePluginType(
-              defaultFirstSuggestion.pluginId,
-              defaultFirstSuggestion.options,
-              defaultFirstSuggestion.fieldConfig
-            );
-          }
-        }
-      })
-    );
-  }
-
   private commitChanges() {
     if (!this.state.isDirty && !this._changesHaveBeenMade) {
       // Nothing to commit
@@ -151,9 +132,6 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
     const changedState = layoutItem.state;
     const originalState = this._layoutItemState!;
 
-    this.setState({ editPreview: undefined });
-    this.state.optionsPane?.setState({ editPreviewRef: undefined });
-
     // Temp fix for old edit mode
     if (this._layoutItem instanceof DashboardGridItem && !config.featureToggles.dashboardNewLayouts) {
       this._layoutItem.handleEditChange();
@@ -242,7 +220,6 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
     // First time initialization
     if (this.state.isInitializing) {
       this.setOriginalState(this.state.panelRef);
-
       this._setupChangeDetection();
       this._updateDataPane(plugin);
 
@@ -255,17 +232,12 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
         })
       );
 
-      const isUnconfigured = Boolean(
-        config.featureToggles.newVizSuggestions && panel.state.pluginId === UNCONFIGURED_PANEL_PLUGIN_ID
-      );
-
       // Setup options pane
       const optionsPane = new PanelOptionsPane({
         panelRef: this.state.panelRef,
-        editPreviewRef: this.state.editPreview?.getRef(),
         searchQuery: '',
         listMode: OptionFilter.All,
-        isVizPickerOpen: isUnconfigured,
+        isVizPickerOpen: this.state.isNewPanel,
         isNewPanel: this.state.isNewPanel,
       });
 
@@ -273,27 +245,6 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
         optionsPane,
         isInitializing: false,
       });
-
-      this._subs.add(
-        optionsPane.subscribeToState((newState, oldState) => {
-          if (newState.isVizPickerOpen !== oldState.isVizPickerOpen) {
-            const panel = this.state.panelRef.resolve();
-            let editPreview: VizPanel | undefined;
-            if (newState.isVizPickerOpen) {
-              // we just "pick" timeseries, viz type will likely be overridden by Suggestions.
-              const editPreviewBuilder = PanelBuilders.timeseries()
-                .setTitle(panel.state.title)
-                .setDescription(panel.state.description);
-              if (panel.state.$data) {
-                editPreviewBuilder.setData(new DataProviderSharer({ source: panel.state.$data.getRef() }));
-              }
-              editPreview = editPreviewBuilder.build();
-            }
-            this.setState({ editPreview });
-            optionsPane.setState({ editPreviewRef: editPreview?.getRef() });
-          }
-        })
-      );
     } else {
       // plugin changed after first time initialization
       // Just update data pane
@@ -320,7 +271,7 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
 
     if (!skipDataQuery) {
       if (!this.state.dataPane) {
-        const dataPane = PanelDataPane.createFor(this.getPanel());
+        const dataPane = PanelDataPane.createFor(this.getPanel(), this.state.useQueryExperienceNext);
         this.setState({ dataPane });
         // This is to notify UrlSyncManager that a new object has been added to scene that requires url sync
         this.publishEvent(new NewSceneObjectAddedEvent(dataPane), true);
@@ -442,10 +393,27 @@ export class PanelEditor extends SceneObjectBase<PanelEditorState> {
         .build(),
     });
   };
+
+  /**
+   * Toggle between v1 and v2 query editor.
+   */
+  public onToggleQueryEditorVersion = () => {
+    const newUseQueryExperienceNext = !this.state.useQueryExperienceNext;
+    const dataPane = PanelDataPane.createFor(this.getPanel(), newUseQueryExperienceNext);
+
+    this.setState({
+      useQueryExperienceNext: newUseQueryExperienceNext,
+      dataPane,
+    });
+
+    // This is to notify UrlSyncManager that a new object has been added to scene that requires url sync
+    this.publishEvent(new NewSceneObjectAddedEvent(dataPane), true);
+  };
 }
 
 export function buildPanelEditScene(panel: VizPanel, isNewPanel = false): PanelEditor {
   return new PanelEditor({
+    useQueryExperienceNext: config.featureToggles.queryEditorNext,
     isInitializing: true,
     panelRef: panel.getRef(),
     isNewPanel,
